$(document).ready(function() {
	var editor = $("#editor");
	var input = $(".edit-control input");
	var colCount;
	var rowCount = 100;
	var head = editor.find("thead");
	var body = editor.find("tbody");
	var alphabet = "abcdefghijklmnopqrstuvwxyz".split("");
	var headRow = $("<tr />");
	var activeCell = $();
	var fontSizeInput = $(".fontSizeControl input[name=fontSize]");

	var bgSel, colorSel;

	function initToolbar() {
		var formatBtns = $(".formatter");
		var fontSel = $(".fontformatter select");
		colorSel = $(".colorformatter select");
		bgSel = $(".backgroundformatter select");

		formatBtns.click(function () {
			activeCell.toggleClass($(this).data("format"));
		});

		fontSel.change(function () {
			activeCell.css({
				fontFamily: $(this).val()
			});
		});

		bgSel.change(function () {
			activeCell.css({
				background: "#" + $(this).val()
			});
		});

		colorSel.change(function () {
			activeCell.css({
				color: "#" + $(this).val()
			});
		});

		$(".resetFormatting").click(function () {
			activeCell.removeAttr("style");
			activeCell.removeAttr("class");
			activeCell.addClass("active");
		});

		$(".fontSizeControl .increment").click(onFontSizeIncrement);
		$(".fontSizeControl .decrement").click(onFontSizeDecrement);

		fontSizeInput.change(onFontSizeInputChange);

	}

	function init() {
		generateTable();
		activeCell = editor.find("td:nth-child(2)");

		body.find("td").not("td.first").click(onCellClick);

		input.keyup(function () {
			activeCell.text($(this).val());
		});

		initToolbar();
		input.attr("disabled", true);
	}

	function generateTable() {
		headRow.append("<th/>");
		colCount = alphabet.length;
		$.each(alphabet, function (key, val) {
			headRow.append("<th>" + val.toUpperCase() + "</th>");
		})
		head.append(headRow);

		for (var i = 0; i < 100; i++) {
			var row = $("<tr />");

			row.append("<td class='first'>" + (i+1) + "</td>")

			$.each(alphabet, function (key, val) {
				row.append($("<td/>"));
			})

			body.append(row);
			
		}
	}

	function onCellClick() {
		activeCell.removeClass("active");
		activeCell = $(this);
		activeCell.addClass("active");

		fontSizeInput.val(getFontSize(activeCell[0]));

		input.attr("disabled", false);
		input.val(activeCell.text());
		input.focus();
	}

	function setActiveCell(el) {
		var $el = $(el);
		activeCell.removeClass("active");
		activeCell = $el;
		activeCell.addClass("active");

		fontSizeInput.val(getFontSize(activeCell[0]));


		input.attr("disabled", false);
		input.val(activeCell.text());
	}


	function onFontSizeIncrement() {
		var newVal = new Number(fontSizeInput.val()) + 1;
		fontSizeSet(newVal);
	}

	function onFontSizeDecrement() {
		var newVal = new Number(fontSizeInput.val()) - 1;
		fontSizeSet(newVal);
	}

	function onFontSizeInputChange() {
		var newVal = new Number(fontSizeInput.val());
		fontSizeSet(newVal);
	}


	function fontSizeSet(newVal) {
		fontSizeInput.val(newVal);
		activeCell.css("font-size", newVal + "px");
	}

	function getFontSize(el) {
		var style = window.getComputedStyle(el, null).getPropertyValue('font-size');
		return parseFloat(style); 
	}


	init();

	$(document).keydown(function(e) {
	var colIndex = activeCell.index();
	var rowIndex = activeCell.parent().index();

	

    switch(e.which) {
        case 37:
        if(colIndex != 1)
        	setActiveCell(editor.find("tr:nth-child("+ (rowIndex+1) +") td:nth-child(" + colIndex + ")"));
        break;

        case 38: // up
        if(rowIndex != 0)
        	setActiveCell(editor.find("tr:nth-child("+ (rowIndex) +") td:nth-child(" + (colIndex+1) + ")"));
        break;

        case 9:
        case 39: // right
        if(colIndex != colCount)
        	setActiveCell(editor.find("tr:nth-child("+ (rowIndex+1) +") td:nth-child(" + (colIndex+2) + ")"));
        break;

        case 13:
        case 40: // down
        if(rowIndex != (rowCount-1))
        	setActiveCell(editor.find("tr:nth-child("+ (rowIndex+2) +") td:nth-child(" + (colIndex+1) + ")"));
        break;

        default: return; // exit this handler for other keys
    }
    e.preventDefault(); // prevent the default action (scroll / move caret)
});


	$(window).resize(function() {
		$(".table-wrap").height($(this).innerHeight() - $('header.main-header').height());
	});
});